![typer-repyt-logo](images/logo-light.png#only-light)
![typer-repyt-logo](images/logo-dark.png#only-dark)

# typer-repyt


_Tools to extended functionality for typer based CLIs_


!!!warning "Open to work"

    I'm looking for a job right now! If you know of any openings that match my skill-set, please let me know! You can
    read my resume over at my [cv site](https://cv.dusktreader.dev). Thanks!

## Overview

This Python package adds extended functionality for Typer CLIs.

Many features are planned, but these are the ones that are available thus far:

- [Building Commands Dynamically](features/build_command.md)
- [Settings management commands](features/settings.md)

